/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.client;

import org.jdtaus.core.container.Dependency;

/**
 * Extension to {@code Dependency} adding properties for XML processing.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: XMLDependency.java 4590 2008-03-10 01:40:58Z schulte2005 $
 */
public class XMLDependency extends Dependency
{
    //--Constants---------------------------------------------------------------

    /** Serial version UID for backwards compatibility with 1.0.x classes. */
    private static final long serialVersionUID = 864707502659749306L;

    //---------------------------------------------------------------Constants--
    //--XMLDependency-----------------------------------------------------------

    /**
     * Value of property {@code specificationIdentifier}.
     * @serial
     */
    private String specificationIdentifier;

    /**
     * Value of property {@code implementationName}.
     * @serial
     */
    private String implementationName;

    /**
     * Flag indicating if properties are defined for the dependency.
     * @serial
     */
    private boolean propertiesDefined;

    /**
     * Getter for property {@code specificationIdentifier}.
     *
     * @return identifier of the specification.
     */
    public String getSpecificationIdentifier()
    {
        return this.specificationIdentifier;
    }

    /**
     * Setter for property {@code specificationIdentifier}.
     *
     * @param value new identifier of the specification.
     */
    public void setSpecificationIdentifier( final String value )
    {
        if ( ( this.specificationIdentifier == null
            ? value != null
            : !this.specificationIdentifier.equals( value ) ) )
        {
            this.setSpecification( null );
        }

        this.specificationIdentifier = value;
    }

    /**
     * Getter for property {@code implementationName}.
     *
     * @return name of the implementation.
     */
    public String getImplementationName()
    {
        return this.implementationName;
    }

    /**
     * Setter for property {@code implementationName}.
     *
     * @param value new name of the implementation.
     */
    public void setImplementationName( final String value )
    {
        if ( ( this.implementationName == null
            ? value != null
            : !this.implementationName.equals( value ) ) )
        {
            this.setImplementation( null );
        }

        this.implementationName = value;
    }

    /**
     * Gets a flag indicating if properties are defined for the dependency.
     *
     * @return {@code true} if properties are defined for the dependency;
     * {@code false} if not.
     */
    public boolean isPropertiesDefined()
    {
        return this.propertiesDefined;
    }

    /**
     * Setter for property {@code propertiesDefined}.
     *
     * @param value {@code true} if properties are defined for the dependency;
     * {@code false} if not.
     */
    public void setPropertiesDefined( boolean value )
    {
        this.propertiesDefined = value;
    }

    //-----------------------------------------------------------XMLDependency--
}
